# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bproto.proto\x12\x0bneodynamics\"\x07\n\x05\x45mpty\")\n\x12ObservationRequest\x12\x13\n\x0bobservation\x18\x01 \x01(\x0c\" \n\x0e\x41\x63tionResponse\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x0c\"]\n\x0bInitRequest\x12\x18\n\x0brender_mode\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tinit_args\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x42\x0e\n\x0c_render_modeB\x0c\n\n_init_args\"L\n\x0cResetRequest\x12\x11\n\x04seed\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x14\n\x07options\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x42\x07\n\x05_seedB\n\n\x08_options\"\x1d\n\x0bStepRequest\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x0c\"2\n\rResetResponse\x12\x13\n\x0bobservation\x18\x01 \x01(\x0c\x12\x0c\n\x04info\x18\x02 \x01(\x0c\"h\n\x0cStepResponse\x12\x13\n\x0bobservation\x18\x01 \x01(\x0c\x12\x0e\n\x06reward\x18\x02 \x01(\x0c\x12\x12\n\nterminated\x18\x03 \x01(\x0c\x12\x11\n\ttruncated\x18\x04 \x01(\x0c\x12\x0c\n\x04info\x18\x05 \x01(\x0c\"%\n\x0eRenderResponse\x12\x13\n\x0brender_data\x18\x01 \x01(\x0c\"r\n\x05Space\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03low\x18\x02 \x03(\x01\x12\x0c\n\x04high\x18\x03 \x03(\x01\x12\x0e\n\x01n\x18\x04 \x01(\x05H\x00\x88\x01\x01\x12\x0c\n\x04nvec\x18\x05 \x03(\x05\x12\r\n\x05shape\x18\x06 \x03(\x05\x12\r\n\x05\x64type\x18\x07 \x01(\tB\x04\n\x02_n\"\xb4\x02\n\x0eSpacesResponse\x12L\n\x11observation_space\x18\x01 \x03(\x0b\x32\x31.neodynamics.SpacesResponse.ObservationSpaceEntry\x12(\n\x0c\x61\x63tion_space\x18\x02 \x01(\x0b\x32\x12.neodynamics.Space\x12\x10\n\x08num_envs\x18\x03 \x01(\x05\x12\x36\n\x10\x65nvironment_type\x18\x04 \x01(\x0e\x32\x1c.neodynamics.EnvironmentType\x12\x13\n\x0brender_mode\x18\x05 \x01(\t\x1aK\n\x15ObservationSpaceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.neodynamics.Space:\x02\x38\x01*/\n\x0f\x45nvironmentType\x12\x0c\n\x08STANDARD\x10\x00\x12\x0e\n\nVECTORIZED\x10\x01\x32\xc6\x02\n\x12\x45nvironmentService\x12?\n\x04Init\x12\x18.neodynamics.InitRequest\x1a\x1b.neodynamics.SpacesResponse\"\x00\x12@\n\x05Reset\x12\x19.neodynamics.ResetRequest\x1a\x1a.neodynamics.ResetResponse\"\x00\x12=\n\x04Step\x12\x18.neodynamics.StepRequest\x1a\x19.neodynamics.StepResponse\"\x00\x12;\n\x06Render\x12\x12.neodynamics.Empty\x1a\x1b.neodynamics.RenderResponse\"\x00\x12\x31\n\x05\x43lose\x12\x12.neodynamics.Empty\x1a\x12.neodynamics.Empty\"\x00\x32\x9b\x01\n\x0c\x41gentService\x12>\n\tGetSpaces\x12\x12.neodynamics.Empty\x1a\x1b.neodynamics.SpacesResponse\"\x00\x12K\n\tGetAction\x12\x1f.neodynamics.ObservationRequest\x1a\x1b.neodynamics.ActionResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SPACESRESPONSE_OBSERVATIONSPACEENTRY']._loaded_options = None
  _globals['_SPACESRESPONSE_OBSERVATIONSPACEENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENTTYPE']._serialized_start=942
  _globals['_ENVIRONMENTTYPE']._serialized_end=989
  _globals['_EMPTY']._serialized_start=28
  _globals['_EMPTY']._serialized_end=35
  _globals['_OBSERVATIONREQUEST']._serialized_start=37
  _globals['_OBSERVATIONREQUEST']._serialized_end=78
  _globals['_ACTIONRESPONSE']._serialized_start=80
  _globals['_ACTIONRESPONSE']._serialized_end=112
  _globals['_INITREQUEST']._serialized_start=114
  _globals['_INITREQUEST']._serialized_end=207
  _globals['_RESETREQUEST']._serialized_start=209
  _globals['_RESETREQUEST']._serialized_end=285
  _globals['_STEPREQUEST']._serialized_start=287
  _globals['_STEPREQUEST']._serialized_end=316
  _globals['_RESETRESPONSE']._serialized_start=318
  _globals['_RESETRESPONSE']._serialized_end=368
  _globals['_STEPRESPONSE']._serialized_start=370
  _globals['_STEPRESPONSE']._serialized_end=474
  _globals['_RENDERRESPONSE']._serialized_start=476
  _globals['_RENDERRESPONSE']._serialized_end=513
  _globals['_SPACE']._serialized_start=515
  _globals['_SPACE']._serialized_end=629
  _globals['_SPACESRESPONSE']._serialized_start=632
  _globals['_SPACESRESPONSE']._serialized_end=940
  _globals['_SPACESRESPONSE_OBSERVATIONSPACEENTRY']._serialized_start=865
  _globals['_SPACESRESPONSE_OBSERVATIONSPACEENTRY']._serialized_end=940
  _globals['_ENVIRONMENTSERVICE']._serialized_start=992
  _globals['_ENVIRONMENTSERVICE']._serialized_end=1318
  _globals['_AGENTSERVICE']._serialized_start=1321
  _globals['_AGENTSERVICE']._serialized_end=1476
# @@protoc_insertion_point(module_scope)
